restructured member variable names


git-svn-id: https://asn1c.svn.sourceforge.net/svnroot/asn1c/trunk@952 59561ff5-6e30-0410-9f3c-9617f08c8826
diff --git a/libasn1parser/asn1p_xports.h b/libasn1parser/asn1p_xports.h
index 8f4fade..da90de5 100644
--- a/libasn1parser/asn1p_xports.h
+++ b/libasn1parser/asn1p_xports.h
@@ -17,8 +17,11 @@
 	/*
 	 * Module name and optional OID, occur after FROM.
 	 */
-	char *from;		/* Name of the module */
-	asn1p_oid_t *from_oid;	/* Optional OID of the module */
+	char *fromModuleName;		/* Name of the module */
+	struct AssignedIdentifier {
+		asn1p_oid_t *oid;	/* Optional OID of the module */
+		asn1p_value_t *value;	/* DefinedValue */
+	} identifier;
 
 	/*
 	 * Number of entities to import.